@@ -2,7 +2,7 @@ from testforPPshare.stock.macro.eastmoney import *
 from testforPPshare.util.text import paramter_wrong
 
 
-def get_chinbor(period):
+def get_chinbor(period='ON'):
     """
     获取中国银行同业间拆借市场数据（chinbor）
     Parameters
@@ -24,7 +24,7 @@ def get_chinbor(period):
     return get_bor(market_code='002', curr_type='CNY', period=period)
 
 
-def get_libor(curr_type, period):
+def get_libor(curr_type='USD', period='ON'):
     """
     获取伦敦银行同业间拆借市场数据（Libor）
     Parameters
@@ -49,7 +49,7 @@ def get_libor(curr_type, period):
     return get_bor(market_code='003', curr_type=curr_type, period=period)
 
 
-def get_euribor(period):
+def get_euribor(period='ON'):
     """
     获取欧洲银行同业间拆借市场数据（eurinbor）
     Parameters
@@ -76,7 +76,7 @@ def get_euribor(period):
     return get_bor(market_code='004', curr_type='EUR', period=period)
 
 
-def get_hibor(curr_type, period):
+def get_hibor(curr_type='USD', period='ON'):
     """
     获取香港银行同业间拆借市场数据（hibor）
     Parameters
@@ -104,7 +104,7 @@ def get_hibor(curr_type, period):
     return get_bor(market_code='005', curr_type=curr_type, period=period)
 
 
-def get_sibor(curr_type, period):
+def get_sibor(curr_type='USD', period='1M'):
     """
     获取新加坡银行同业间拆借市场数据（sibor）
     Parameters
